"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assetresponse import AssetResponse, AssetResponseTypedDict
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListAssetsResponseTypedDict(TypedDict):
    results: List[AssetResponseTypedDict]
    pagination: DbModelPaginationResponseTypedDict


class ListAssetsResponse(BaseModel):
    results: List[AssetResponse]

    pagination: DbModelPaginationResponse
