"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequestTypedDict(TypedDict):
    user_email: str
    key_name: NotRequired[str]


class CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequest(BaseModel):
    user_email: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    key_name: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "default"
