"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GenericSuccessResponseTypedDict(TypedDict):
    message: str
    success: NotRequired[bool]


class GenericSuccessResponse(BaseModel):
    message: str

    success: Optional[bool] = True
