"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AssignmentMode(str, Enum):
    r"""Mode for how classifications should be assigned"""

    THRESHOLD = "threshold"
    NEAREST = "nearest"
