"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AssetsModelSearchQueryTypedDict(TypedDict):
    key: List[str]
    r"""Fields to search in. Can be a list of field names or '*' for all fields"""
    value: str
    r"""The search term to look for in the specified fields"""


class AssetsModelSearchQuery(BaseModel):
    key: List[str]
    r"""Fields to search in. Can be a list of field names or '*' for all fields"""

    value: str
    r"""The search term to look for in the specified fields"""
