"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assignmentconfig import AssignmentConfig, AssignmentConfigTypedDict
from .logicaloperator import LogicalOperator, LogicalOperatorTypedDict
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DiscoverRequestTypedDict(TypedDict):
    collections: List[str]
    r"""List of collection names or ids to search for features"""
    filters: NotRequired[Nullable[LogicalOperatorTypedDict]]
    r"""Filters to apply to the discovery task"""
    assignment: NotRequired[AssignmentConfigTypedDict]
    r"""Configuration for how classifications should be assigned to features"""
    limit: NotRequired[Nullable[int]]
    r"""Number of feature samples to process, if None, all features that match the filters are processed"""


class DiscoverRequest(BaseModel):
    collections: List[str]
    r"""List of collection names or ids to search for features"""

    filters: OptionalNullable[LogicalOperator] = UNSET
    r"""Filters to apply to the discovery task"""

    assignment: Optional[AssignmentConfig] = None
    r"""Configuration for how classifications should be assigned to features"""

    limit: OptionalNullable[int] = UNSET
    r"""Number of feature samples to process, if None, all features that match the filters are processed"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["filters", "assignment", "limit"]
        nullable_fields = ["filters", "limit"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
