"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UpdateAssetRequestMetadataTypedDict(TypedDict):
    r"""Updated metadata for the asset. This can include any key-value pairs that should be updated or added to the asset's metadata."""


class UpdateAssetRequestMetadata(BaseModel):
    r"""Updated metadata for the asset. This can include any key-value pairs that should be updated or added to the asset's metadata."""


class UpdateAssetRequestTypedDict(TypedDict):
    propagate_features: NotRequired[Nullable[bool]]
    r"""If True, the features will be propagated to all assets with the same asset_id"""
    metadata: NotRequired[UpdateAssetRequestMetadataTypedDict]
    r"""Updated metadata for the asset. This can include any key-value pairs that should be updated or added to the asset's metadata."""


class UpdateAssetRequest(BaseModel):
    propagate_features: OptionalNullable[bool] = UNSET
    r"""If True, the features will be propagated to all assets with the same asset_id"""

    metadata: Optional[UpdateAssetRequestMetadata] = None
    r"""Updated metadata for the asset. This can include any key-value pairs that should be updated or added to the asset's metadata."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["propagate_features", "metadata"]
        nullable_fields = ["propagate_features"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
