"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .featureresponse import FeatureResponse, FeatureResponseTypedDict
from .features_model_paginationresponse import (
    FeaturesModelPaginationResponse,
    FeaturesModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListFeaturesResponseTypedDict(TypedDict):
    results: List[FeatureResponseTypedDict]
    pagination: FeaturesModelPaginationResponseTypedDict


class ListFeaturesResponse(BaseModel):
    results: List[FeatureResponse]

    pagination: FeaturesModelPaginationResponse
