"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SparseEmbeddingTypedDict(TypedDict):
    indices: List[int]
    r"""Indices for sparse vector"""
    values: List[float]
    r"""Values for sparse vector"""


class SparseEmbedding(BaseModel):
    indices: List[int]
    r"""Indices for sparse vector"""

    values: List[float]
    r"""Values for sparse vector"""
