"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DenseEmbeddingTypedDict(TypedDict):
    vector: List[float]
    r"""Dense vector representation"""


class DenseEmbedding(BaseModel):
    vector: List[float]
    r"""Dense vector representation"""
