"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class HealthCheckResponseTypedDict(TypedDict):
    status: str


class HealthCheckResponse(BaseModel):
    status: str
