"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .taxonomynode import TaxonomyNode, TaxonomyNodeTypedDict
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TaxonomyModelTypedDict(TypedDict):
    taxonomy_name: str
    r"""Taxonomy name"""
    nodes: List[TaxonomyNodeTypedDict]
    r"""Taxonomy nodes"""
    taxonomy_id: NotRequired[str]
    r"""Auto-generated taxonomy identifier"""


class TaxonomyModel(BaseModel):
    taxonomy_name: str
    r"""Taxonomy name"""

    nodes: List[TaxonomyNode]
    r"""Taxonomy nodes"""

    taxonomy_id: Optional[str] = None
    r"""Auto-generated taxonomy identifier"""
