"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .classificationwithfeature import (
    ClassificationWithFeature,
    ClassificationWithFeatureTypedDict,
)
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListClassificationsResponseTypedDict(TypedDict):
    r"""Response for the list classifications endpoint"""

    results: List[ClassificationWithFeatureTypedDict]
    r"""List of classification entries with optional enriched data"""
    pagination: DbModelPaginationResponseTypedDict


class ListClassificationsResponse(BaseModel):
    r"""Response for the list classifications endpoint"""

    results: List[ClassificationWithFeature]
    r"""List of classification entries with optional enriched data"""

    pagination: DbModelPaginationResponse
