"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dateusage import DateUsage, DateUsageTypedDict
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UsageTypedDict(TypedDict):
    total_credits: int
    dates: List[DateUsageTypedDict]


class Usage(BaseModel):
    total_credits: int

    dates: List[DateUsage]
