"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GeoIndexParamsTypedDict(TypedDict):
    r"""Configuration for geo index"""

    type: NotRequired[str]


class GeoIndexParams(BaseModel):
    r"""Configuration for geo index"""

    type: Optional[str] = "geo"
