"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class VectorModel(str, Enum):
    IMAGE = "image"
    OPENAI_CLIP_VIT_BASE_PATCH32 = "openai-clip-vit-base-patch32"
    MULTIMODAL = "multimodal"
    VERTEX_MULTIMODAL = "vertex-multimodal"
    TEXT = "text"
    BAAI_BGE_M3 = "baai-bge-m3"
    KEYWORD = "keyword"
    NAVER_SPLADE_V3 = "naver-splade-v3"
