"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Permission(str, Enum):
    READ = "read"
    WRITE = "write"
    VIEW = "view"
    CREATE = "create"
    UPDATE = "update"
    DELETE = "delete"
    SUPER = "super"
    ADMIN = "admin"
    MANAGE_USERS = "manage_users"
    MANAGE_BILLING = "manage_billing"
    MANAGE_SETTINGS = "manage_settings"
    READ_PUBLIC = "read_public"
    READ_PRIVATE = "read_private"
    WRITE_PUBLIC = "write_public"
    WRITE_PRIVATE = "write_private"
