"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TokenizerType(str, Enum):
    WORD = "word"
    WHITESPACE = "whitespace"
    PREFIX = "prefix"
    MULTILINGUAL = "multilingual"
