"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class PayloadIndexTypeTypedDict(TypedDict):
    r"""Simple schema for payload index type"""

    type: str


class PayloadIndexType(BaseModel):
    r"""Simple schema for payload index type"""

    type: str
