"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IntegerIndexParamsTypedDict(TypedDict):
    r"""Configuration for integer index"""

    type: NotRequired[str]
    lookup: NotRequired[bool]
    range: NotRequired[bool]


class IntegerIndexParams(BaseModel):
    r"""Configuration for integer index"""

    type: Optional[str] = "integer"

    lookup: Optional[bool] = True

    range: Optional[bool] = True
