"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assetfeatures import AssetFeatures, AssetFeaturesTypedDict
from .assetresponse import AssetResponse, AssetResponseTypedDict
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class GroupedAssetDataTypedDict(TypedDict):
    asset: AssetResponseTypedDict
    features: AssetFeaturesTypedDict


class GroupedAssetData(BaseModel):
    asset: AssetResponse

    features: AssetFeatures
