"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .taxonomynodecreate import TaxonomyNodeCreate, TaxonomyNodeCreateTypedDict
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TaxonomyCreateTypedDict(TypedDict):
    taxonomy_name: str
    r"""Taxonomy name (must not contain spaces or special characters)"""
    nodes: List[TaxonomyNodeCreateTypedDict]


class TaxonomyCreate(BaseModel):
    taxonomy_name: str
    r"""Taxonomy name (must not contain spaces or special characters)"""

    nodes: List[TaxonomyNodeCreate]
