"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usermodel_output import UserModelOutput, UserModelOutputTypedDict
from datetime import datetime
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OrganizationModelMetadataTypedDict(TypedDict):
    pass


class OrganizationModelMetadata(BaseModel):
    pass


class OrganizationModelTypedDict(TypedDict):
    organization_name: str
    organization_id: NotRequired[str]
    internal_id: NotRequired[str]
    created_at: NotRequired[datetime]
    account_type: NotRequired[str]
    credit_count: NotRequired[int]
    metadata: NotRequired[OrganizationModelMetadataTypedDict]
    users: NotRequired[List[UserModelOutputTypedDict]]


class OrganizationModel(BaseModel):
    organization_name: str

    organization_id: Optional[str] = None

    internal_id: Optional[str] = None

    created_at: Optional[datetime] = None

    account_type: Optional[str] = "free"

    credit_count: Optional[int] = 1000

    metadata: Optional[OrganizationModelMetadata] = None

    users: Optional[List[UserModelOutput]] = None
