"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TaskStatus(str, Enum):
    DONE = "DONE"
    FAILED = "FAILED"
    SKIPPED = "SKIPPED"
    CANCELLED = "CANCELLED"
    PROCESSING = "PROCESSING"
    DOWNLOADING = "DOWNLOADING"
    INITIALIZING = "INITIALIZING"
    UPLOADING = "UPLOADING"
    QUEUED = "QUEUED"
    PENDING = "PENDING"
