"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class Mode(str, Enum):
    r"""Update mode: 'replace' or 'append'"""

    REPLACE = "replace"
    APPEND = "append"


class AssetUpdateTypedDict(TypedDict):
    asset_id: str
    r"""Unique identifier for the asset to be updated"""
    mode: Mode
    r"""Update mode: 'replace' or 'append'"""


class AssetUpdate(BaseModel):
    asset_id: str
    r"""Unique identifier for the asset to be updated"""

    mode: Mode
    r"""Update mode: 'replace' or 'append'"""
