"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class VectorType(str, Enum):
    SPARSE = "sparse"
    DENSE = "dense"
