"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .availablemodels import AvailableModels
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TaxonomyExtractionConfigTypedDict(TypedDict):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy_ids: List[str]
    r"""List of taxonomy IDs to use for classification"""
    embedding_models: List[AvailableModels]
    r"""Vector indexes to use for classification"""
    confidence_threshold: NotRequired[float]
    r"""Minimum confidence score required for classification"""


class TaxonomyExtractionConfig(BaseModel):
    r"""Configuration for taxonomy-based entity extraction during ingestion"""

    taxonomy_ids: List[str]
    r"""List of taxonomy IDs to use for classification"""

    embedding_models: List[AvailableModels]
    r"""Vector indexes to use for classification"""

    confidence_threshold: Optional[float] = 0.8
    r"""Minimum confidence score required for classification"""
