"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteNamespaceV1NamespacesNamespaceDeleteRequestTypedDict(TypedDict):
    namespace: str
    r"""Either the namespace name or namespace ID"""


class DeleteNamespaceV1NamespacesNamespaceDeleteRequest(BaseModel):
    namespace: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Either the namespace name or namespace ID"""
