"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "mixpeek"
__version__: str = "0.18.2"
__openapi_doc_version__: str = "0.81"
__gen_version__: str = "2.493.32"
__user_agent__: str = "speakeasy-sdk/python 0.18.2 2.493.32 0.81 mixpeek"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
