"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class FeatureUpdateRequestMetadataTypedDict(TypedDict):
    pass


class FeatureUpdateRequestMetadata(BaseModel):
    pass


class FeatureUpdateRequestTypedDict(TypedDict):
    metadata: FeatureUpdateRequestMetadataTypedDict


class FeatureUpdateRequest(BaseModel):
    metadata: FeatureUpdateRequestMetadata
