"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class Direction(str, Enum):
    r"""Sort direction"""

    ASC = "asc"
    DESC = "desc"


class SortOptionTypedDict(TypedDict):
    field: str
    r"""Field to sort by, supports dot notation for nested fields"""
    direction: Direction
    r"""Sort direction"""


class SortOption(BaseModel):
    field: str
    r"""Field to sort by, supports dot notation for nested fields"""

    direction: Direction
    r"""Sort direction"""
