"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatenamespacerequest import (
    UpdateNamespaceRequest,
    UpdateNamespaceRequestTypedDict,
)
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateNamespaceV1NamespacesNamespacePutRequestTypedDict(TypedDict):
    namespace: str
    r"""Either the namespace name or namespace ID"""
    update_namespace_request: UpdateNamespaceRequestTypedDict


class UpdateNamespaceV1NamespacesNamespacePutRequest(BaseModel):
    namespace: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Either the namespace name or namespace ID"""

    update_namespace_request: Annotated[
        UpdateNamespaceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
