"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .permission import Permission
from datetime import datetime
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class APIKeyTypedDict(TypedDict):
    key: NotRequired[str]
    name: NotRequired[str]
    created_at: NotRequired[datetime]
    permissions: NotRequired[List[Permission]]


class APIKey(BaseModel):
    key: Optional[str] = None

    name: Optional[str] = None

    created_at: Optional[datetime] = None

    permissions: Optional[List[Permission]] = None
